@@ -4,6 +4,7 @@ import click
 from gitutor.init.commands import init
 from gitutor.save.commands import save
 from gitutor.ignore.commands import ignore
+from gitutor.compare.commands import compare
 
 @click.group()
 @click.pass_context
@@ -26,6 +27,7 @@ def cli(ctx):
 cli.add_command(init)
 cli.add_command(save)
 cli.add_command(ignore)
+cli.add_command(compare)
 
 def main():
     cli(obj={})
